/************************************************************************/
/*                                                                      */
/*  Licensed Materials - Property of IBM                                */
/*  WA84 SupportPac                                                     */
/*  (c) Copyright IBM Corp. 2001                                        */
/*  US Government Users Restricted Rights - Use, duplication or         */
/*  disclosure restricted by GSA ADP Schedule Contract                  */
/*  with IBM Corp.                                                      */
/*                                                                      */
/************************************************************************/
package com.ibm.workflow.servlet.clientx.wext;

import java.util.*;
import javax.servlet.http.*;

/**
* This class is a container of parameter-value pair in the HTTP-request.
* All methods is the same as the ServletRequest methods.
*/
public class PostedValues implements java.io.Serializable {
    Hashtable table;

    /**
    * Constructor.
    * @param request    the request the client has made of the servlet
    */
    public PostedValues(HttpServletRequest request) {
        table = new Hashtable();
        for (Enumeration enum = request.getParameterNames(); enum.hasMoreElements();) {
            String name = (String)enum.nextElement();
            String[] values = request.getParameterValues(name);
            table.put(name, values);
        }
    }

    /**
    * Returns an Enumeration of String objects containing the names of
    * the parameters contained in this request.
    * @return   an Enumeration object of parameter names
    */
    public Enumeration getParameterNames() {
        return table.keys();
    }

    /**
    * Returns an array of String objects containing all of the values
    * the given request parameter has, or null if the parameter does not exist.
    * @param name   a String containing the name of the parameter
                    whose value is requested
    * @return       an array of String objects containing the parameter's values
    */
    public String[] getParameterValues(String name) {
        return (String[])table.get(name);
    }

    /**
    * Returns the value of a request parameter as a String,
    * or null if the parameter does not exist.
    * @param name   a String specifying the name of the parameter
    * @return   a String representing the single value of the parameter
    */
    public String getParameter(String name) {
        String[] values = getParameterValues(name);
        if (values != null && values.length > 0)
            return values[0];
        return null;
    }
}
